@@ -42,7 +42,6 @@
 #include <vimode/keyparser.h>
 #include <vimode/keymapper.h>
 #include <vimode/emulatedcommandbar.h>
-#include "katepartdebug.h"
 #include "kateviinputmode.h"
 #include "marks.h"
 #include "jumps.h"
@@ -101,6 +100,7 @@ InputModeManager::~InputModeManager()
     delete m_viReplaceMode;
     delete m_jumps;
     delete m_marks;
+    delete m_searcher;
     delete m_macroRecorder;
     delete m_completionRecorder;
     delete m_completionReplayer;
@@ -162,20 +162,17 @@ void InputModeManager::feedKeyPresses(const QString &keyPresses) const
     Qt::KeyboardModifiers mods;
     QString text;
 
-    foreach (const QChar &c, keyPresses) {
+    foreach (QChar c, keyPresses) {
         QString decoded = KeyParser::self()->decodeKeySequence(QString(c));
         key = -1;
         mods = Qt::NoModifier;
         text.clear();
 
-        qCDebug(LOG_PART) << "\t" << decoded;
-
         if (decoded.length() > 1) {  // special key
 
             // remove the angle brackets
             decoded.remove(0, 1);
             decoded.remove(decoded.indexOf(QLatin1String(">")), 1);
-            qCDebug(LOG_PART) << QLatin1String("\t Special key:") << decoded;
 
             // check if one or more modifier keys where used
             if (decoded.indexOf(QLatin1String("s-")) != -1 || decoded.indexOf(QLatin1String("c-")) != -1
@@ -210,9 +207,6 @@ void InputModeManager::feedKeyPresses(const QString &keyPresses) const
                 } else if (decoded.length() == 1) {
                     key = int(decoded.at(0).toUpper().toLatin1());
                     text = decoded.at(0);
-                    qCDebug(LOG_PART) << "###########" << key;
-                } else {
-                    qCWarning(LOG_PART) << "decoded is empty. skipping key press.";
                 }
             } else { // no modifiers
                 key = KeyParser::self()->vi2qt(decoded);
@@ -326,7 +320,6 @@ bool InputModeManager::isAnyVisualMode() const
     case ViMode::ReplaceMode:
         return m_viReplaceMode;
     }
-    qCDebug(LOG_PART) << "WARNING: Unknown Vi mode.";
     return NULL;
 }
 
@@ -335,7 +328,9 @@ void InputModeManager::viEnterNormalMode()
     bool moveCursorLeft = (m_currentViMode == ViMode::InsertMode || m_currentViMode == ViMode::ReplaceMode)
                           && m_viewInternal->getCursor().column() > 0;
 
-    if (!m_lastChangeRecorder->isReplaying() && m_currentViMode == ViMode::InsertMode) {
+    if (!m_lastChangeRecorder->isReplaying() &&
+            (m_currentViMode == ViMode::InsertMode ||
+             m_currentViMode == ViMode::ReplaceMode)) {
         // '^ is the insert mark and "^ is the insert register,
         // which holds the last inserted text
         KTextEditor::Range r(m_view->cursorPosition(), m_marks->getInsertStopped());
@@ -364,7 +359,7 @@ void InputModeManager::viEnterInsertMode()
     if (getTemporaryNormalMode()) {
         // Ensure the key log contains a request to re-enter Insert mode, else the keystrokes made
         // after returning from temporary normal mode will be treated as commands!
-        m_lastChangeRecorder->record(QKeyEvent(QEvent::KeyPress, Qt::Key_I, Qt::NoModifier, QLatin1String("i")));
+        m_lastChangeRecorder->record(QKeyEvent(QEvent::KeyPress, Qt::Key_I, Qt::NoModifier, QStringLiteral("i")));
     }
     m_inputAdapter->setCaretStyle(KateRenderer::Line);
     setTemporaryNormalMode(false);
@@ -386,6 +381,7 @@ void InputModeManager::viEnterVisualMode(ViMode mode)
 void InputModeManager::viEnterReplaceMode()
 {
     changeViMode(ViMode::ReplaceMode);
+    m_marks->setStartEditYanked(KTextEditor::Cursor(m_view->cursorPosition()));
     m_inputAdapter->setCaretStyle(KateRenderer::Underline);
     m_viewInternal->update();
 }
